==> ejc-outcontract-impl-3.0.0-20220127.034554-35-sources.jar: com/ejianc/foundation/outcontract/bean/RecordOutcontractEquipmentLeaseItemEntity.java <==
package com.ejianc.foundation.outcontract.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 记录租赁物进出场费明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_record_outcontract_equipment_lease_item")
public class RecordOutcontractEquipmentLeaseItemEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="record_outcontract_id")
    private Long recordOutcontractId; // 记录合同id
    @TableField(value="equipment_id")
    private Long equipmentId; // 物资id
    @TableField(value="equipment_category_id")
    private Long equipmentCategoryId; // 物资分类id
    @TableField(value="equipment_category_name")
    private String equipmentCategoryName; // 物资分类名称
    @TableField(value="equipment_code")
    private String equipmentCode; // 物资编码
    @TableField(value="equipment_name")
    private String equipmentName; // 物资名称
    @TableField(value="equipment_spec")
    private String equipmentSpec; // 规格型号
    @TableField(value="equipment_unit")
    private String equipmentUnit; // 计量单位
    @TableField(value="entrance_exit_fee")
    private BigDecimal entranceExitFee; // 进出场费（元/台）
    @TableField(value="quantity")
    private Integer quantity; // 台数
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率（%）
    @TableField(value="total_price")
    private BigDecimal totalPrice; // 合价
    @TableField(value="remark")
    private String remark; // 备注
    
    
    

    public Long getRecordOutcontractId() {
        return recordOutcontractId;
    }

    public void setRecordOutcontractId(Long recordOutcontractId) {
        this.recordOutcontractId = recordOutcontractId;
    }
    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }
    public Long getEquipmentCategoryId() {
        return equipmentCategoryId;
    }

    public void setEquipmentCategoryId(Long equipmentCategoryId) {
        this.equipmentCategoryId = equipmentCategoryId;
    }
    public String getEquipmentCategoryName() {
        return equipmentCategoryName;
    }

    public void setEquipmentCategoryName(String equipmentCategoryName) {
        this.equipmentCategoryName = equipmentCategoryName;
    }
    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public String getEquipmentSpec() {
        return equipmentSpec;
    }

    public void setEquipmentSpec(String equipmentSpec) {
        this.equipmentSpec = equipmentSpec;
    }
    public String getEquipmentUnit() {
        return equipmentUnit;
    }

    public void setEquipmentUnit(String equipmentUnit) {
        this.equipmentUnit = equipmentUnit;
    }
    public BigDecimal getEntranceExitFee() {
        return entranceExitFee;
    }

    public void setEntranceExitFee(BigDecimal entranceExitFee) {
        this.entranceExitFee = entranceExitFee;
    }
    public Integer getQuantity() {
        return quantity;
    }

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getTotalPrice() {
        return totalPrice;
    }

    public void setTotalPrice(BigDecimal totalPrice) {
        this.totalPrice = totalPrice;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
}

==> ejc-outcontract-impl-3.0.0-20250107.020835-237-sources.jar: com/ejianc/foundation/outcontract/bean/RecordOutcontractEquipmentLeaseItemEntity.java <==
package com.ejianc.foundation.outcontract.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 记录租赁物进出场费明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_record_outcontract_equipment_lease_item")
public class RecordOutcontractEquipmentLeaseItemEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="record_outcontract_id")
    private Long recordOutcontractId; // 记录合同id
    @TableField(value="equipment_id")
    private Long equipmentId; // 物资id
    @TableField(value="equipment_category_id")
    private Long equipmentCategoryId; // 物资分类id
    @TableField(value="equipment_category_name")
    private String equipmentCategoryName; // 物资分类名称
    @TableField(value="equipment_category_code")
    private String equipmentCategoryCode; // 物资分类编码
    @TableField(value="equipment_code")
    private String equipmentCode; // 物资编码
    @TableField(value="equipment_name")
    private String equipmentName; // 物资名称
    @TableField(value="equipment_spec")
    private String equipmentSpec; // 规格型号
    @TableField(value="equipment_unit")
    private String equipmentUnit; // 计量单位
    @TableField(value="entrance_exit_fee")
    private BigDecimal entranceExitFee; // 进出场费（元/台）
    @TableField(value="quantity")
    private Integer quantity; // 台数
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率（%）
    @TableField(value="total_price")
    private BigDecimal totalPrice; // 合价
    @TableField(value="remark")
    private String remark; // 备注
    
    
    

    public Long getRecordOutcontractId() {
        return recordOutcontractId;
    }

    public void setRecordOutcontractId(Long recordOutcontractId) {
        this.recordOutcontractId = recordOutcontractId;
    }
    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }
    public Long getEquipmentCategoryId() {
        return equipmentCategoryId;
    }

    public void setEquipmentCategoryId(Long equipmentCategoryId) {
        this.equipmentCategoryId = equipmentCategoryId;
    }
    public String getEquipmentCategoryName() {
        return equipmentCategoryName;
    }

    public void setEquipmentCategoryName(String equipmentCategoryName) {
        this.equipmentCategoryName = equipmentCategoryName;
    }
    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public String getEquipmentSpec() {
        return equipmentSpec;
    }

    public void setEquipmentSpec(String equipmentSpec) {
        this.equipmentSpec = equipmentSpec;
    }
    public String getEquipmentUnit() {
        return equipmentUnit;
    }

    public void setEquipmentUnit(String equipmentUnit) {
        this.equipmentUnit = equipmentUnit;
    }
    public BigDecimal getEntranceExitFee() {
        return entranceExitFee;
    }

    public void setEntranceExitFee(BigDecimal entranceExitFee) {
        this.entranceExitFee = entranceExitFee;
    }
    public Integer getQuantity() {
        return quantity;
    }

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getTotalPrice() {
        return totalPrice;
    }

    public void setTotalPrice(BigDecimal totalPrice) {
        this.totalPrice = totalPrice;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

	public String getEquipmentCategoryCode() {
		return equipmentCategoryCode;
	}

	public void setEquipmentCategoryCode(String equipmentCategoryCode) {
		this.equipmentCategoryCode = equipmentCategoryCode;
	}
    
}
